summaryrefslogtreecommitdiff
path: root/include/libnsgif.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/libnsgif.h')
-rw-r--r--include/libnsgif.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/libnsgif.h b/include/libnsgif.h
index b281034..6b8d521 100644
--- a/include/libnsgif.h
+++ b/include/libnsgif.h
@@ -43,8 +43,8 @@ typedef struct gif_frame {
/** offset (in bytes) to the GIF frame data */
uint32_t frame_pointer;
- /** whether the frame has previously been used */
- bool virgin;
+ /** whether the frame has previously been decoded. */
+ bool decoded;
/** whether the frame is totally opaque */
bool opaque;
/** whether a full image redraw is required */